@@ -52,8 +52,7 @@ class LineGraph:
         if tool_tip_items is None:
             tool_tip_items = []
 
-        detail_tooltips = [(e, "@{%s}" % e) for e in tool_tip_items]
-
+        detail_tooltips = [(e, f"@{{{e}}}") for e in tool_tip_items]
         hover_tool = HoverTool(tooltips=[("index", "$index"), ("(x,y)", "($x, $y)")] + detail_tooltips)
         return hover_tool
 
