@@ -16,37 +16,36 @@ import annofabcli
 import annofabcli.common.cli
 from annofabcli import AnnofabApiFacade
 from annofabcli.common.cli import (
-    AbstracCommandCinfirmInterface,
+    COMMAND_LINE_ERROR_STATUS_CODE,
     AbstractCommandLineInterface,
+    AbstractCommandLineWithConfirmInterface,
     ArgumentParser,
     build_annofabapi_resource_and_login,
 )
 from annofabcli.common.facade import TaskQuery, match_task_with_query
+from annofabcli.common.utils import add_dryrun_prefix
 
 logger = logging.getLogger(__name__)
 
 
-class RejectTasksMain(AbstracCommandCinfirmInterface):
-    def __init__(self, service: annofabapi.Resource, all_yes: bool = False):
+class RejectTasksMain(AbstractCommandLineWithConfirmInterface):
+    def __init__(self, service: annofabapi.Resource, *, comment_data: Optional[Dict[str, Any]], all_yes: bool = False):
         self.service = service
         self.facade = AnnofabApiFacade(service)
-        AbstracCommandCinfirmInterface.__init__(self, all_yes)
+        self.comment_data = comment_data
+        AbstractCommandLineWithConfirmInterface.__init__(self, all_yes)
 
     def add_inspection_comment(
         self,
         project_id: str,
-        project_input_data_type: InputDataType,
         task: Dict[str, Any],
         inspection_comment: str,
     ):
         """
         検査コメントを付与する。
-        画像プロジェクトなら先頭画像の左上に付与する。
-        動画プロジェクトなら最初の区間に付与する。
 
         Args:
             project_id:
-            project_input_data_type: プロジェクトの入力データの種類
             task:
             inspection_comment:
 
@@ -55,10 +54,6 @@ class RejectTasksMain(AbstracCommandCinfirmInterface):
 
         """
         first_input_data_id = task["input_data_id_list"][0]
-        if project_input_data_type == InputDataType.MOVIE:
-            inspection_data = {"start": 0, "end": 100, "_type": "Time"}
-        else:
-            inspection_data = {"x": 0, "y": 0, "_type": "Point"}
 
         req_inspection = [
             {
@@ -70,7 +65,7 @@ class RejectTasksMain(AbstracCommandCinfirmInterface):
                     "inspection_id": str(uuid.uuid4()),
                     "phase": task["phase"],
                     "commenter_account_id": self.service.api.account_id,
-                    "data": inspection_data,
+                    "data": self.comment_data,
                     "status": "annotator_action_required",
                     "created_datetime": task["updated_datetime"],
                 },
@@ -169,13 +164,13 @@ class RejectTasksMain(AbstracCommandCinfirmInterface):
         self,
         project_id: str,
         task_id: str,
-        project_input_data_type: InputDataType,
         inspection_comment: Optional[str] = None,
         assign_last_annotator: bool = True,
         assigned_annotator_user_id: Optional[str] = None,
         cancel_acceptance: bool = False,
         task_query: Optional[TaskQuery] = None,
         task_index: Optional[int] = None,
+        dryrun: bool = False,
     ) -> bool:
         """
         タスクを強制的に差し戻す
@@ -213,14 +208,15 @@ class RejectTasksMain(AbstracCommandCinfirmInterface):
         ):
             return False
 
-        if task["status"] == TaskStatus.COMPLETE.value and cancel_acceptance:
+        if task["status"] == TaskStatus.COMPLETE.value and cancel_acceptance and not dryrun:
             self._cancel_acceptance(task)
 
         if inspection_comment is not None:
             changed_task = self.change_to_working_status(project_id, task)
             try:
                 # 検査コメントを付与する
-                self.add_inspection_comment(project_id, project_input_data_type, changed_task, inspection_comment)
+                if not dryrun:
+                    self.add_inspection_comment(project_id, changed_task, inspection_comment)
                 logger.debug(f"{logging_prefix} : task_id = {task_id}, 検査コメントの付与 完了")
 
             except requests.exceptions.HTTPError:
@@ -232,36 +228,40 @@ class RejectTasksMain(AbstracCommandCinfirmInterface):
             # タスクを差し戻す
             if assign_last_annotator:
                 # 最後のannotation phaseに担当を割り当てる
-                self.facade.reject_task_assign_last_annotator(project_id, task_id)
+                if not dryrun:
+                    self.facade.reject_task_assign_last_annotator(project_id, task_id)
                 logger.info(f"{logging_prefix} : task_id = {task_id} のタスクを差し戻しました。タスクの担当者は直前の教師付フェーズの担当者。")
                 return True
 
-            else:
-                # 指定したユーザに担当を割り当てる
+            # 指定したユーザに担当を割り当てる
+            if not dryrun:
                 self.facade.reject_task(
                     project_id,
                     task_id,
                     account_id=self.service.api.account_id,
                     annotator_account_id=assigned_annotator_account_id,
                 )
-                str_annotator_user = f"タスクの担当者: {assigned_annotator_user_id}"
-                logger.info(f"{logging_prefix} : task_id = {task_id} の差し戻し完了. {str_annotator_user}")
-                return True
+            str_annotator_user = f"タスクの担当者: {assigned_annotator_user_id}"
+            logger.info(f"{logging_prefix} : task_id = {task_id} の差し戻し完了. {str_annotator_user}")
+            return True
 
         except requests.exceptions.HTTPError as e:
             logger.warning(e)
             logger.warning(f"{logging_prefix} : task_id = {task_id} タスクの差し戻しに失敗")
 
-            new_task = self.service.wrapper.get_task_or_none(project_id, task_id)
-            if new_task["status"] == TaskStatus.WORKING.value and new_task["account_id"] == self.service.api.account_id:
-                self.facade.change_to_break_phase(project_id, task_id)
+            if not dryrun:
+                new_task = self.service.wrapper.get_task_or_none(project_id, task_id)
+                if (
+                    new_task["status"] == TaskStatus.WORKING.value
+                    and new_task["account_id"] == self.service.api.account_id
+                ):
+                    self.facade.change_to_break_phase(project_id, task_id)
             return False
 
     def reject_task_for_task_wrapper(
         self,
         tpl: Tuple[int, str],
         project_id: str,
-        project_input_data_type: InputDataType,
         inspection_comment: Optional[str] = None,
         assign_last_annotator: bool = True,
         assigned_annotator_user_id: Optional[str] = None,
@@ -273,7 +273,6 @@ class RejectTasksMain(AbstracCommandCinfirmInterface):
             project_id=project_id,
             task_id=task_id,
             task_index=task_index,
-            project_input_data_type=project_input_data_type,
             inspection_comment=inspection_comment,
             assign_last_annotator=assign_last_annotator,
             assigned_annotator_user_id=assigned_annotator_user_id,
@@ -291,25 +290,23 @@ class RejectTasksMain(AbstracCommandCinfirmInterface):
         cancel_acceptance: bool = False,
         task_query: Optional[TaskQuery] = None,
         parallelism: Optional[int] = None,
+        dryrun: bool = False,
     ) -> None:
         if task_query is not None:
             task_query = self.facade.set_account_id_of_task_query(project_id, task_query)
 
-        project, _ = self.service.api.get_project(project_id)
-        project_input_data_type = InputDataType(project["input_data_type"])
-
         logger.info(f"差し戻すタスク数: {len(task_id_list)}")
 
         if parallelism is not None:
             partial_func = partial(
                 self.reject_task_for_task_wrapper,
                 project_id=project_id,
-                project_input_data_type=project_input_data_type,
                 inspection_comment=inspection_comment,
                 assign_last_annotator=assign_last_annotator,
                 assigned_annotator_user_id=assigned_annotator_user_id,
                 cancel_acceptance=cancel_acceptance,
                 task_query=task_query,
+                dryrun=dryrun,
             )
             with multiprocessing.Pool(parallelism) as pool:
                 result_bool_list = pool.map(partial_func, enumerate(task_id_list))
@@ -323,12 +320,12 @@ class RejectTasksMain(AbstracCommandCinfirmInterface):
                     project_id,
                     task_id,
                     task_index=task_index,
-                    project_input_data_type=project_input_data_type,
                     inspection_comment=inspection_comment,
                     assign_last_annotator=assign_last_annotator,
                     assigned_annotator_user_id=assigned_annotator_user_id,
                     cancel_acceptance=cancel_acceptance,
                     task_query=task_query,
+                    dryrun=dryrun,
                 )
                 if result:
                     success_count += 1
@@ -337,13 +334,13 @@ class RejectTasksMain(AbstracCommandCinfirmInterface):
 
 
 class RejectTasks(AbstractCommandLineInterface):
-    @staticmethod
-    def validate(args: argparse.Namespace) -> bool:
-        COMMON_MESSAGE = "annofabcli task reject: error:"
+    COMMON_MESSAGE = "annofabcli task reject: error:"
+
+    def validate(self, args: argparse.Namespace) -> bool:
 
         if args.parallelism is not None and not args.yes:
             print(
-                f"{COMMON_MESSAGE} argument --parallelism: '--parallelism'を指定するときは、必ず'--yes'を指定してください。",
+                f"{self.COMMON_MESSAGE} argument --parallelism: '--parallelism'を指定するときは、必ず'--yes'を指定してください。",
                 file=sys.stderr,
             )
             return False
@@ -353,7 +350,10 @@ class RejectTasks(AbstractCommandLineInterface):
     def main(self):
         args = self.args
         if not self.validate(args):
-            return
+            sys.exit(COMMAND_LINE_ERROR_STATUS_CODE)
+
+        if args.dryrun:
+            add_dryrun_prefix(logger)
 
         task_id_list = annofabcli.common.cli.get_list_from_args(args.task_id)
         assign_last_annotator = not args.not_assign and args.assigned_annotator_user_id is None
@@ -363,7 +363,23 @@ class RejectTasks(AbstractCommandLineInterface):
         dict_task_query = annofabcli.common.cli.get_json_from_args(args.task_query)
         task_query: Optional[TaskQuery] = TaskQuery.from_dict(dict_task_query) if dict_task_query is not None else None
 
-        main_obj = RejectTasksMain(self.service, all_yes=self.all_yes)
+        comment_data = annofabcli.common.cli.get_json_from_args(args.comment_data)
+        project, _ = self.service.api.get_project(args.project_id)
+        if args.comment is not None and comment_data is None:
+            if project["input_data_type"] == InputDataType.IMAGE.value:
+                comment_data = {"x": 0, "y": 0, "_type": "Point"}
+            elif project["input_data_type"] == InputDataType.MOVIE.value:
+                # 注意：少なくとも0.1秒以上の区間にしないと、Annofab上で検査コメントを確認できない
+                comment_data = {"start": 0, "end": 100, "_type": "Time"}
+            elif project["input_data_type"] == InputDataType.CUSTOM.value:
+                # customプロジェクト
+                print(
+                    f"{self.COMMON_MESSAGE} argument --comment_data: カスタムプロジェクトに検査コメントを付与する場合は必須です。",
+                    file=sys.stderr,
+                )
+                return
+
+        main_obj = RejectTasksMain(self.service, comment_data=comment_data, all_yes=self.all_yes)
         main_obj.reject_task_list(
             args.project_id,
             task_id_list,
@@ -373,6 +389,7 @@ class RejectTasks(AbstractCommandLineInterface):
             cancel_acceptance=args.cancel_acceptance,
             task_query=task_query,
             parallelism=args.parallelism,
+            dryrun=args.dryrun,
         )
 
 
@@ -392,7 +409,17 @@ def parse_args(parser: argparse.ArgumentParser):
         "-c",
         "--comment",
         type=str,
-        help="差し戻すときに付与する検査コメントを指定します。" "画像プロジェクトならばタスク内の先頭の画像の左上(x=0,y=0)に、動画プロジェクトなら動画の先頭（start=0, end=100)に付与します。",
+        help="差し戻すときに付与する検査コメントを指定します。検査コメントはタスク内の先頭画像に付与します。付与する位置は'--comment_data'で指定できます。",
+    )
+
+    parser.add_argument(
+        "--comment_data",
+        type=str,
+        help="検査コメントを付与する位置や区間をJSON形式で指定します。"
+        "指定方法は https://annofab-cli.readthedocs.io/ja/latest/command_reference/task/reject.html を参照してください。"
+        " ``file://`` を先頭に付けると、JSON形式のファイルを指定できます。"
+        "デフォルトでは画像プロジェクトならば画像の左上(x=0,y=0)、動画プロジェクトなら動画の先頭（start=0, end=100)に付与します。"
+        "カスタムプロジェクトに検査コメントを付与する場合は必須です。",
     )
 
     # 差し戻したタスクの担当者の割当に関して
@@ -415,11 +442,12 @@ def parse_args(parser: argparse.ArgumentParser):
     parser.add_argument(
         "--parallelism", type=int, help="使用するプロセス数（並列度）を指定してください。指定する場合は必ず'--yes'を指定してください。指定しない場合は、逐次的に処理します。"
     )
+    parser.add_argument("--dryrun", action="store_true", help="差し戻しが行われた時の結果を表示しますが、実際はタスクを差し戻しません。")
 
     parser.set_defaults(subcommand_func=main)
 
 
-def add_parser(subparsers: argparse._SubParsersAction):
+def add_parser(subparsers: Optional[argparse._SubParsersAction] = None):
     subcommand_name = "reject"
     subcommand_help = "タスクを差し戻します。"
     description = (
@@ -431,3 +459,4 @@ def add_parser(subparsers: argparse._SubParsersAction):
 
     parser = annofabcli.common.cli.add_parser(subparsers, subcommand_name, subcommand_help, description, epilog=epilog)
     parse_args(parser)
+    return parser
